collect.results.Rdinla.collect.results collect results from a inla-call
inla.collect.results(
results.dir,
debug = FALSE,
only.hyperparam = FALSE,
file.log = NULL,
file.log2 = NULL,
silent = inla.getOption("silent")
)The directory where the results of the inla run are stored
Logical. If TRUE some debugging information are printed
Binary variable indicating wheather only the results for the hyperparameters should be collected
Character. The filename, if any, of the logfile for the internal calculations
Character. The filename, if any, of the logfile2 for the internal calculations
Internal use only
The function returns an object of class "inla", see the help
file for inla for details.
This function is mainly used inside inla to collect results after
running the inla function. It can also be used to collect results into R
after having run an inla section outside R.