control.compute.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.compute(
openmp.strategy = "default",
hyperpar = TRUE,
return.marginals = TRUE,
return.marginals.predictor = FALSE,
dic = FALSE,
mlik = TRUE,
cpo = FALSE,
po = FALSE,
waic = FALSE,
residuals = FALSE,
q = FALSE,
config = FALSE,
smtp = NULL,
graph = FALSE,
internal.opt = NULL,
save.memory = NULL,
control.gcpo = INLA::control.gcpo()
)
inla.set.control.compute.default(...)The computational strategy to use: 'small', 'medium', 'large', 'huge', 'default' and 'pardiso'.
A boolean variable if the marginal for the hyperparameters should be computed. Default TRUE.
A boolean variable if the marginals for the latent field should be returned (although it is computed). Default TRUE
A boolean variable if the marginals for the linear predictor should be returned (although it is computed). Default FALSE
A boolean variable if the DIC-value should be computed. Default FALSE.
A boolean variable if the marginal likelihood should be computed.
Default TRUE.
A boolean variable if the cross-validated predictive measures
(cpo, pit) should be computed (default FALSE)
A boolean variable if the predictive ordinate should be computed
(default FALSE)
A boolean variable if the Watanabe-Akaike information criteria
should be computed (default FALSE)
Provide estimates of residuals (whatever we mean by that).
(default FALSE)
Currently only residuals base on expected (saturated) deviance are available.
The sign of the residuals are only very likely correct.
These residuals are not properly justified from a Bayesian point of
view, hence must be used with caution. It is provided in the hope
they would be useful. This feature is EXPERIMENTAL for the moment,
so changes can happen at any time.
A boolean variable if binary images of the precision matrix, the reordered precision matrix and the Cholesky triangle should be generated. (Default FALSE.)
A boolean variable if the internal GMRF approximations be
stored. (Default FALSE.)
The sparse-matrix solver, one of 'default', 'taucs', 'band' or
'pardiso' (default inla.getOption("smtp")). smtp='pardiso' implies
openmp.strategy='pardiso'.
A boolean variable if the graph itself should be returned. (Default FALSE.)
A boolean variable, if to do internal online
optimisations or not. (Default inla.getOption("internal.opt"))
A boolean variable, make choices which saves memory over accuracy. (Default 'inla.getOption("save.memory")')
(For experts only!) Set control variables for the gcpo.
The intended use is to use inla.group.cv.
Refer to control.gcpo, ?inla.group.cv and the vignette for details.
Named arguments passed on to the main function
Other control:
control.bgev(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()