Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.expert(
  cpo.manual = FALSE,
  cpo.idx = -1,
  disable.gaussian.check = FALSE,
  jp = NULL,
  globalconstr = list(A = NULL, e = NULL),
  opt.solve = FALSE,
  opt.storage = FALSE,
  opt.num.threads = TRUE
)

inla.set.control.expert.default(...)

Arguments

cpo.manual

A boolean variable to decide if the inla-program is to be runned in a manual-cpo-mode. (EXPERT OPTION: DO NOT USE)

cpo.idx

The index/indices of the data point(s) to remove. (EXPERIMENTAL OPTION: DO NOT USE)

disable.gaussian.check

Disable the check for fast computations with a Gaussian likelihood and identity link (default FALSE)

jp

An object of class inla.jp defining a joint prior

globalconstr

Add a global constraint (see ?f and argument extraconstr). Note that a global constraint does NOT correct the normalisation constant. (EXPERIMENTAL OPTION)

opt.solve

Store also L^T to optimize linear solves (TAUCS only). Might benefite larger models. (EXPERIMENTAL OPTION)

opt.storage

Make sure L is stored sequencially (TAUCS only). Might benefite larger models. (EXPERIMENTAL OPTION)

opt.num.threads

Reduce the number of threads adaptively if needed at critical places to optimize wall-clock time

...

Named arguments passed on to the main function