control.family.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.family(
dummy = 0,
hyper = NULL,
initial = NULL,
prior = NULL,
param = NULL,
fixed = NULL,
link = "default",
sn.shape.max = 5,
gev.scale.xi = 0.1,
control.bgev = NULL,
cenpoisson.I = c(-1L, -1L),
beta.censor.value = 0,
variant = 0L,
link.simple = "default",
control.mix = NULL,
control.pom = NULL,
control.link = INLA::control.link(),
control.sem = NULL,
cloglike = NULL
)
inla.set.control.family.default(...)A dummy argument that can be used as a workaround
Definition of the hyperparameters
(OBSOLETE!) Initial value for the hyperparameter(s) of the likelihood in the internal scale.
(OBSOLETE!) The name of the prior distribution(s) for othe hyperparameter(s).
(OBSOLETE!) The parameters for the prior distribution
(OBSOLETE!) Boolean variable(s) to say if the hyperparameter(s) is fixed or random.
(OBSOLETE! Use control.link=list(model=) instead.) The
link function to use.
Maximum value for the shape-parameter for Skew Normal observations (default 5.0)
(Expert option, do not use unless you know what you are doing.) The internal scaling of the shape-parameter for the GEV distribution. (default 0.1)
See ?control.bgev
The censoring interval for the censored Poisson
The censor value for the Beta-likelihood (0 <= beta.censor.value < 1/2)
This variable is used to give options for various variants of the likelihood, like chosing different parameterisations for example. See the relevant likelihood documentations for options (does only apply to some likelihoods).
See inla.doc("0inflated")
See ?control.mix
See ?control.pom
See ?control.link
Parameters for likelihood sem
An inla.cloglike object for likelihood cloglike
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()