control.fixed.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.fixed(
cdf = NULL,
quantiles = NULL,
expand.factor.strategy = "model.matrix",
mean = 0,
mean.intercept = 0,
prec = 0.001,
prec.intercept = 0,
compute = TRUE,
correlation.matrix = FALSE,
remove.names = NULL
)
inla.set.control.fixed.default(...)A list of values to compute the CDF for, for all fixed effects
A list of quantiles to compute for all fixed effects
The strategy used to expand factors into fixed
effects based on their levels. The default strategy is us use the
model.matrix-function for which NA's are not allowed
(expand.factor.strategy="model.matrix") and levels are possible removed.
The alternative option (expand.factor.strategy="inla") use an
inla-specific expansion which expand a factor into one fixed effects for
each level, do allow for NA's and all levels are present in the model. In this
case, factors MUST BE factors in the data.frame/list and NOT added as
.+factor(x1)+. in the formula only.
Prior mean for all fixed effects except the intercept.
Alternatively, a named list with specific means where name=default applies to
unmatched names. For example control.fixed=list(mean=list(a=1, b=2, default=0)) assign 'mean=1' to fixed effect 'a' , 'mean=2' to effect 'b' and
'mean=0' to all others. (default 0.0)
Prior mean for the intercept (default 0.0)
Default precision for all fixed effects except the intercept.
Alternatively, a named list with specific means where name=default applies to
unmatched names. For example control.fixed=list(prec=list(a=1, b=2, default=0.01)) assign 'prec=1' to fixed effect 'a' , 'prec=2' to effect 'b' and
'prec=0.01' to all others. (default 0.001)
Default precision the intercept (default 0.0)
Compute marginals for the fixed effects ? (default TRUE)
Compute the posterior correlation matrix for all
fixed effects? (default FALSE) OOPS: This option will set up appropriate linear
combinations and the results are shown as the posterior correlation matrix of the
linear combinations. This option will imply
control.inla=list(lincomb.derived.correlation.matrix=TRUE).
A vector of names of expanded fixed effects to remove from the model-matrix. This is an expert option, and should only be used if you know what you are doing.
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()