control.gcpo.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.gcpo(
enable = FALSE,
num.level.sets = -1,
size.max = 32,
strategy = c("posterior", "prior"),
groups = NULL,
selection = NULL,
group.selection = NULL,
friends = NULL,
weights = NULL,
verbose = FALSE,
epsilon = 0.005,
prior.diagonal = 1e-04,
correct.hyperpar = TRUE,
keep = NULL,
remove = NULL,
remove.fixed = TRUE,
type.cv = "single"
)
inla.set.control.gcpo.default(...)Number of level.sets to use. The default value
-1 corresponds to leave-one-out cross-validation. If argument weights is
used, then this is threshold for the sum of the weights defining a group.
The maximum size (measure in the number of nodes) of a group. If the computed
group-size is larger, it will be truncated to size.max. Note that: If
weights are in use, then
this still corresponds to the number of nodes in the group, and not the sum of the
weights. This is ment as an emergency option to avoid the size of the
group to go nuts.
One of "posterior" or "prior". See the
vignette for details.
An (optional) predefined list of groups. See the vignette for details.
An optional list of data-indices to use. If not given, then all data are used.
An optional list of data-indices to use when building the
groups. If given, each group beyond the observation itself, must be a subset of
group.selection. If not given, then all data are used.
An optional list of lists of indices to use a friends
An optional positive weight attached to each datapoint. The sum
of the weights define the size of the group. If NULL, then unit weight is
used.
Run with verbose output of some of the internals in
the calculations. This option will also enable inla(..., verbose=TRUE) if its not enabled already.
Two correlations with a difference less than epsilon,
will be classified as identical.
When strategy="prior", prior.diagonal is
added to the diagonal of the prior precision matrix to avoid singularities
For strategy="prior", then this gives a vector of the
name of model-components TO USE when computing the groups. See the vignette
for details. Not both of keep and remove can be defined.
For strategy="prior", then this gives a vector of the
name of model-components NOT TO USE when computing the groups. See the
vignette for details. Not both of keep and remove can be
defined.
For strategy="prior", this is the default option
which is in effect if both keep and remove are NULL. If
TRUE, it will remove (or condition on) all fixed effects when
computing the groups. See the vignette for details.
Type of cv, either "single" (default) or "joint"
Named arguments passed on to the main function
(For experts only!) Set control variables for the gcpo in control.compute.
The intended use is to use inla.group.cv().
Refer to inla.group.cv() and the vignette for details.
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()