control.group.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.group(
model = "exchangeable",
order = NULL,
cyclic = FALSE,
graph = NULL,
scale.model = TRUE,
adjust.for.con.comp = TRUE,
hyper = NULL,
initial = NULL,
fixed = NULL,
prior = NULL,
param = NULL
)
inla.set.control.group.default(...)Group model (one of 'exchangable', 'exchangablepos', 'ar1', 'ar', 'rw1', 'rw2', 'besag', or 'iid')
Defines the order of the model: for model ar this
defines the order p, in AR(p). Not used for other models at the time
being.
Make the group model cyclic? (Only applies to models 'ar1', 'rw1' and 'rw2')
The graph specification (Only applies to model 'besag')
Scale the intrinsic model (RW1, RW2, BESAG) so the
generalized variance is 1. (Default TRUE)
Adjust for connected components when
scale.model=TRUE? (default TRUE)
Definition of the hyperparameter(s)
(OBSOLETE!) The initial value for the group correlation or precision in the internal scale.
(OBSOLETE!) A boolean variable if the group correction or precision is assumed to be fixed or random.
(OBSOLETE!) The name of the prior distribution for the group correlation or precision in the internal scale
(OBSOLETE!) Prior parameters
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()