control.hazard.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.hazard(
model = "rw1",
hyper = NULL,
fixed = FALSE,
initial = NULL,
prior = NULL,
param = NULL,
constr = TRUE,
diagonal = NULL,
n.intervals = 15,
cutpoints = NULL,
strata.name = NULL,
scale.model = NULL
)
inla.set.control.hazard.default(...)The model for the baseline hazard model. One of 'rw1', 'rw2' or 'iid'. (Default 'rw1'.)
The definition of the hyperparameters.
(OBSOLETE!) A boolean variable; is the precision for 'model' fixed? (Default FALSE.)
(OBSOLETE!) The initial value for the precision.
(OBSOLETE!) The prior distribution for the precision for 'model'
(OBSOLETE!) The parameters in the prior distribution
A boolean variable; shall the 'model' be constrained to sum to zero?
An extra constant added to the diagonal of the precision matrix
Number of intervals in the baseline hazard. (Default 15)
The cutpoints to use. If not specified the they are compute from 'n.intervals' and the maximum length of the interval. (Default NULL)
The name of the stratefication variable for the baseline hazard in the data.frame
Scale the baseline hazard model (RW1, RW2) so the
generalized variance is 1. (Default
inla.getOption("scale.model.default").)
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()