Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.lincomb(verbose = FALSE)

inla.set.control.lincomb.default(...)

Arguments

verbose

Use verbose mode for linear combinations if verbose model is set globally. (Default FALSE). This option is only available for the default inla.mode (inla.mode="compact").

...

Named arguments passed on to the main function