control.link.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.link(
model = "default",
order = NULL,
variant = NULL,
hyper = NULL,
quantile = NULL,
a = 1,
initial = NULL,
fixed = NULL,
prior = NULL,
param = NULL
)
inla.set.control.link.default(...)The name of the link function/model
The order of the link function, where the interpretation
of order is model-dependent.
The variant of the link function, where the
interpretation of variant is model-dependent.
Definition of the hyperparameter(s) for the link model chosen
The quantile for quantile link function
The parameter a in the LOGa link
(OBSOLETE!) The initial value(s) for the hyperparameter(s)
(OBSOLETE!) A boolean variable if hyperparmater(s) is/are fixed or random
(OBSOLETE!) The name of the prior distribution(s) for the hyperparmater(s)
(OBSOLETE!) The parameters for the prior distribution(s) for the hyperparmater(s)
Named arguments passed on to the main function
The control.link-list is set within the corresponding control.family-list as the link is likelihood-family specific.
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()