Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.lp.scale(hyper = NULL)

inla.set.control.lp.scale.default(...)

Arguments

hyper

Definition of the hyperparameter(s)

...

Named arguments passed on to the main function