control.mix.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.mix(
model = NULL,
hyper = NULL,
initial = NULL,
fixed = NULL,
prior = NULL,
param = NULL,
npoints = 101,
integrator = "default"
)
inla.set.control.mix.default(...)The model for the random effect. Currently, only
model='gaussian' is implemented
Definition of the hyperparameter(s) for the random effect model chosen
(OBSOLETE!) The initial value(s) for the hyperparameter(s)
(OBSOLETE!) A boolean variable if hyperparmater(s) is/are fixed or random
(OBSOLETE!) The name of the prior distribution(s) for the hyperparmater(s)
(OBSOLETE!) The parameters for the prior distribution(s) for the hyperparmater(s)
Number of points used to do the numerical integration (default 101)
The integration scheme to use (default,
quadrature, simpson)
Named arguments passed on to the main function
The control.mix list is set within the corresponding control.family-list a the mixture of the likelihood is likelihood specific. (This option is EXPERIMENTAL.)
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()