control.mode.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.mode(
result = NULL,
theta = NULL,
x = NULL,
restart = TRUE,
fixed = FALSE
)
inla.set.control.mode.default(...)Previous result-object from inla(), a inla-state object or the name of a
state-file. Use the theta- and x-mode from this object
The theta-mode/initial values for theta. This option has preference over result$mode$theta.
The x-mode/initial values for x. This option has preference over
result$mode$x. (This option is less important than theta can often be
left out, unless result is used for which it is automatically set.)
A boolean variable; should we restart the optimisation from
the given configuration? If TRUE (default), then
use this configuration as the initial
values (both theta and x) and optimize. If FALSE, then use theta as
as the mode and x as the initial value.
If x != NULL, theta=NULL and restart=TRUE, then an error will occour
unless there are no hyperparameters.
A boolean variable. If TRUE then treat all theta's as known and
fixed, and if FALSE (default) then treat all theta's as unknown and random.
If fixed=TRUE and restart=TRUE, then restart is assigned to FALSE and a
warning is issued. Note that fixed=TRUE will change the model as the
corresponding hyperparmaeters will be defined as fixed.
Named arguments passed on to the main function
For internal use only and for algorithms built on to of INLA.
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()