Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.numa(enable = NULL)

Arguments

enable

Enable NUMA aware cache? (NULL used the value inla.getOption("numa").)

Details

Extra options controlling the NUMA awareness (when NUMA is present)