Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.pom(cdf = "logit", fast = FALSE)

inla.set.control.pom.default(...)

Arguments

cdf

character The cdf to use, "logit" (default) or "probit"

fast

Logical Use a faster but approximate form for the probit cdf (default FALSE)?

...

Named arguments passed on to the main function