control.predictor.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.predictor(
hyper = NULL,
fixed = NULL,
prior = NULL,
param = NULL,
initial = NULL,
compute = FALSE,
cdf = NULL,
quantiles = NULL,
cross = NULL,
A = NULL,
precision = exp(15),
link = NULL
)
inla.set.control.predictor.default(...)Definition of the hyperparameters.
(OBSOLETE!) If the precision for the artificial noise is fixed or not (default TRUE)
(OBSOLETE!) The prior for the artificial noise
(OBSOLETE!) Prior parameters for the artificial noise
(OBSOLETE!) The value of the log precision of the artificial noise
A boolean variable; should the marginals for the linear predictor be computed? (Default FALSE.)
A list of values to compute the CDF for the linear predictor
A list of quantiles to compute for the linear predictor
Cross-sum-to-zero constraints with the linear predictor. All linear predictors with the same level of 'cross' are constrained to have sum zero. Use 'NA' for no contribution. 'Cross' has the same length as the linear predictor (including the 'A' matrix extention). (THIS IS AN EXPERIMENTAL OPTION, CHANGES MAY APPEAR.)
The observation matrix (matrix or Matrix::sparseMatrix).
The precision for eta* - A*eta, (default exp(15))
Define the family-connection for unobserved observations
(NA). link is integer values which defines the family connection;
family[link[idx]] unless is.na(link[idx]) for which the
identity-link is used. The link-argument only influence the
fitted.values in the result-object. If is.null(link)
(default) then the identity-link is used for all missing observations. If the
length of link is 1, then this value is replicated with the length of the
response vector. If an element of the response vector is !NA then the
corresponding entry in link is not used (but must still be a legal value).
Setting this variable implies compute=TRUE.
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()