Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.scopy(covariate = NULL, n = 11)

inla.set.control.scopy.default(...)

Arguments

covariate

The covariate for the scopy function

n

Number of locations in the RW2 (n = 2 or 5 <= n <= 15)

...

Named arguments passed on to the main function