Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.sem(B = NULL, idx = 0)

inla.set.control.sem.default(...)

Arguments

B

The symbolic B-matrix, where each element is a string giving the expression for that particular element, in terms of beta-parameters for copy

idx

Which diagonal element to use for the variance.

...

Named arguments passed on to the main function

Details

Parameters to family sem