Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.stiles(verbose = FALSE, block.size = -1, param = rep(-1, 20))

inla.set.control.stiles.default(...)

Arguments

verbose

Show detailed output (default FALSE)

block.size

(integer) Preferred number of rhs's in each parallel solve. Used to split many rhs's into threads. Default value (-1) is to use the 'tile.size' from sTiles, which is a reasonable tradeoff between speed and memory use. A higher value will increase memory usage.

param

An integer vector of parameters (variable length). Default values are given by '-1'. See sTiles documentation for explaination of these parameters

...

Named arguments passed on to the main function

Details

Extra options controlling the sTiles library