Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.taucs(min.block.size = 4, block.size = 64)

inla.set.control.taucs.default(...)

Arguments

block.size

Preferred number of rhs's in each parallel solve. Used to split many rhs's into threads (on the outer level)

...

Named arguments passed on to the main function

Details

Extra options controlling the TAUCS library