Control variables in control.* for use with inla(). The functions can be used to TAB-complete arguments, and returns a list of the default control arguments, unless overridden by specific input arguments.

control.update(result = NULL)

inla.set.control.update.default(...)

Arguments

result

Update the joint posterior for the hyperparameters from result

...

Named arguments passed on to the main function