control.vb.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
Logical/Character Use this feature? If "auto" this will be selected automatically.
Character What to correct, either "mean" or "variance".
Logical Be verbose or not.
Integer Maximum number of iterations.
Numeric If the standardized correction for the mean is larger than this value, then call the vb.correction off and issue a warning
Vector of length 4. The size limit to correct for a f().
First element is for strategy="mean".
Second element is for strategy="variance".
Third element is overall maximum dimension of the correction for strategy="mean".
Forth element is overall maximum dimension of the correction for strategy="variance".
How many times the Hessian is updated for each correction.
Select strategy for computing the Hessian
matrix for strategy="variance", one of "full",
"diagonal", "partial" and "default".
Named arguments passed on to the main function
control.vb List of arguments for various VB corrections.
Used for control.inla control.vb specifications.
Other control:
control.bgev(),
control.compute(),
control.expert(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update()