dryrun.Rd
Do a dryrun to get information about the internal storage and the list (and ordering) of the hyperparameters
inla.dryrun(...)
Same arguments as inla()
inla
A list of start-index and length for each latent component and a list of the hyperparameters in the model
Havard Rue hrue@r-inla.org