group.cv.RdFrom a fitted model, compute and add the group.cv-values
inla.group.cv(
result,
group.cv = NULL,
num.level.sets = -1,
strategy = c("posterior", "prior"),
size.max = 32,
groups = NULL,
selection = NULL,
group.selection = NULL,
friends = NULL,
weights = NULL,
verbose = FALSE,
epsilon = 0.005,
prior.diagonal = 1e-04,
keep = NULL,
remove = NULL,
remove.fixed = TRUE,
type.cv = "single"
)An object of class inla, ie a result of a call to
inla().
If given, the groups are taken from this argument.
group.cv must be the output of previous call to
inla.group.cv().
Number of level.sets to use. The default value
-1 corresponds to leave-one-out cross-validation. If argument weights is
used, then this is threshold for the sum of the weights defining a group.
One of "posterior" or "prior". See the
vignette for details.
The maximum size (measure in the number of nodes) of a group. If the computed
group-size is larger, it will be truncated to size.max. Note that: If
weights are in use, then
this still corresponds to the number of nodes in the group, and not the sum of the
weights. This is ment as an emergency option to avoid the size of the
group to go nuts.
An (optional) predefined list of groups. See the vignette for details.
An optional list of data-indices to use. If not given, then all data are used.
An optional list of data-indices to use when building the
groups. If given, each group beyond the observation itself, must be a subset of
group.selection. If not given, then all data are used.
An optional list of lists of indices to use a friends
An optional positive weight attached to each datapoint. The sum
of the weights define the size of the group. If NULL, then unit weight is
used.
Run with verbose output of some of the internals in
the calculations. This option will also enable inla(..., verbose=TRUE) if its not enabled already.
Two correlations with a difference less than epsilon,
will be classified as identical.
When strategy="prior", prior.diagonal is
added to the diagonal of the prior precision matrix to avoid singularities
For strategy="prior", then this gives a vector of the
name of model-components TO USE when computing the groups. See the vignette
for details. Not both of keep and remove can be defined.
For strategy="prior", then this gives a vector of the
name of model-components NOT TO USE when computing the groups. See the
vignette for details. Not both of keep and remove can be
defined.
For strategy="prior", this is the default option
which is in effect if both keep and remove are NULL. If
TRUE, it will remove (or condition on) all fixed effects when
computing the groups. See the vignette for details.
Type of cv, either "single" (default) or "joint"
The object returned is list related to leave-group-out cross-validation. See the vignette for details.