iidkd component (experimental)iidkd.RdThis function provide samples of the iidkd component using more
interpretable parameters
inla.iidkd.sample(n = 10^4, result, name, return.cov = FALSE)Integer Number of samples to use
inla-object An object of class inla, ie a result of a
call to inla()
Character The name of the iidkd component
Logical Return samples of the covariance matrix instead of stdev/correlation matrix described below?
A list of sampled matrices, with (default) correlations on the off-diagonal and standard-deviations on the diagonal
inla.doc("iidkd")