[Deprecated] in favour of fmesher::fm_CRS()

Creates either a CRS object or an inla.CRS object, describing a coordinate reference system.

inla.CRS(..., args = NULL)

inla.wkt_predef()

Arguments

...

Arguments passed on to fmesher::fm_CRS(...).

args

list of named proj4 arguments.

Value

Either an sp::CRS object or an inla.CRS object, depending on if the coordinate reference system described by the parameters can be expressed with a pure sp::CRS object or not.

An S3 inla.CRS object is a list, usually (but not necessarily) containing at least one element:

crs

The basic sp::CRS object

inla.wkt_predef returns a WKT2 string defining a projection

inla.wkt_predef returns a WKT2 string defining a projection

Functions

Author

Finn Lindgren finn.lindgren@gmail.com

Examples

if (require("sf")) {
    crs1 <- fmesher::fm_crs("longlat_globe")
    crs2 <- fmesher::fm_crs("lambert_globe")
    crs3 <- fmesher::fm_crs("mollweide_norm")
    crs4 <- fmesher::fm_crs("hammer_globe")
    crs5 <- fmesher::fm_crs("sphere")
    crs6 <- fmesher::fm_crs("globe")
}
if (FALSE) { # \dontrun{
names(inla.wkt_predef())
} # }

if (FALSE) { # \dontrun{
names(inla.wkt_predef())
} # }