Detect whether PROJ6 is available for INLA. Deprecated and always returns TRUE.

inla.has_PROJ6()

inla.not_for_PROJ6(fun)

inla.not_for_PROJ4(fun)

inla.fallback_PROJ6(fun)

inla.requires_PROJ6(fun)

Arguments

fun

The name of the calling function

Value

For inla.has_PROJ6, always returns TRUE. Previously: logical; TRUE if PROJ6 is available, FALSE otherwise

Details

inla.has_PROJ6 is called to check if PROJ6&GDAL3 are available.

Functions

  • inla.has_PROJ6(): [Deprecated]

  • inla.not_for_PROJ6(): [Deprecated] Called to warn about using old PROJ4 features even though PROJ6 is available

  • inla.not_for_PROJ4(): [Deprecated] Called to give an error when calling methods that are only available for PROJ6

  • inla.fallback_PROJ6(): [Deprecated] Called to warn about falling back to using old PROJ4 methods when a PROJ6 method hasn't been implemented

  • inla.requires_PROJ6(): [Deprecated] Called to give an error when PROJ6 is required but not available

Examples

if (FALSE) { # \dontrun{
inla.has_PROJ6()
} # }