[Deprecated] since 23.08.18. Use fmesher::fm_segm() instead.

Constructs an list of inla.mesh.segment object from boundary or interior constraint information in an inla.mesh() object.

inla.mesh.boundary(mesh, grp = NULL)

inla.mesh.interior(mesh, grp = NULL)

Arguments

mesh

An inla.mesh object.

grp

Group indices to extract. If NULL, all boundary/interior constrain groups are extracted.

Value

A list of inla.mesh.segment objects.

Author

Finn Lindgren finn.lindgren@gmail.com

Examples


loc <- matrix(runif(100 * 2) * 1000, 100, 2)
mesh <- fmesher::fm_mesh_2d_inla(loc.domain = loc, max.edge = c(50, 500))
boundary <- inla.mesh.boundary(mesh)
#> Warning: `inla.mesh.boundary()` was deprecated in INLA 23.08.18.
#>  Please use `fmesher::fm_segm(mesh, boundary = TRUE)` instead.
#>  For more information, see
#>   https://inlabru-org.github.io/fmesher/articles/inla_conversion.html
#>  To silence these deprecation messages in old legacy code, set
#>   `inla.setOption(fmesher.evolution.warn = FALSE)`.
#>  To ensure visibility of these messages in package tests, also set
#>   `inla.setOption(fmesher.evolution.verbosity = 'warn')`.
interior <- inla.mesh.interior(mesh)
#> Warning: `inla.mesh.interior()` was deprecated in INLA 23.08.18.
#>  Please use `fmesher::fm_segm(mesh, boundary = FALSE)` instead.
#>  For more information, see
#>   https://inlabru-org.github.io/fmesher/articles/inla_conversion.html
#>  To silence these deprecation messages in old legacy code, set
#>   `inla.setOption(fmesher.evolution.warn = FALSE)`.
#>  To ensure visibility of these messages in package tests, also set
#>   `inla.setOption(fmesher.evolution.verbosity = 'warn')`.