[Deprecated] since 23.08.18. Use fmesher::fm_mesh_2d_inla() instead.

Create a triangle mesh based on initial point locations, specified or automatic boundaries, and mesh quality parameters.

inla.mesh.create.helper(points = NULL, points.domain = NULL, ...)

Arguments

points

Matrix of point locations to be used as initial triangulation nodes.

points.domain

Matrix of point locations used to determine the domain extent.

...

Additional arguments passed on to inla.mesh.2d().

Note

Obsolete function kept for backwards compatibility. Use fmesher::fm_mesh_2d_inla() instead.

See also

Author

Finn Lindgren finn.lindgren@gmail.com