[Deprecated] Use fmesher::fm_CRS() instead.

Wrapper for CRS(projargs) (PROJ4) and CRS(wkt) for sp::Spatial objects.

This function is a convenience method to workaround PROJ4/PROJ6 differences, and the lack of a crs extraction method for Spatial objects.

inla.sp_get_crs(x)

Arguments

x

A sp::Spatial object

Value

A CRS object, or NULL if no valid CRS identified

Author

Finn Lindgren finn.lindgren@gmail.com

Examples

if (FALSE) { # \dontrun{
if (require("sp", quietly = TRUE) && interactive()) {
    s <- sp::SpatialPoints(matrix(1:6, 3, 2), proj4string = fmesher::fm_CRS("sphere"))
    inla.sp_get_crs(s)
}
} # }