inla.spde.make.block.A.RdConstructs observation/prediction weight matrices for numerical integration
schemes for regional data problems. Primarily intended for internal use by
inla.spde.make.A().
A precomputed observation/prediction matrix for locations that are to be joined.
Indices specifying block groupings: Entries with the same
block value are joined into a single row in the resulting matrix, and
the block values are the row indices.
The number of blocks.
Optional scaling weights to be applied row-wise to the input
A matrix.
Specifies what scaling method should be used when joining the
rows of the A matrix as grouped by the block specification.
'none': Straight sum, no rescaling.
'count': Divide by the number of entries in the block.
'weights': Divide by the sum of the weight values within each
block.
'sum': Divide by the resulting row sums.