Create a linear combination or several linear combinations, as input to inla(..., lincomb = <lincomb>)

inla.make.lincomb(...)

inla.make.lincombs(...)

Arguments

...

Arguments; see examples

Value

A structure to be passed on to inla() argument lincomb

See also

TODO

Author

Havard Rue hrue@r-inla.org

Examples


##See the worked out examples and description in the OLD-FAQ
##vignette {vignette("old-faq", package="INLA")}