meshbuilder.RdInteractively design and build a triangle mesh for use with SPDE models, and assess the finite element approximation errors. The R code needed to recreate the mesh outside the interactive Shiny app is also generated. Spatial objects can be imported from the global workspace.
meshbuilder()if (FALSE) { # \dontrun{
meshbuilder()
} # }