options.RdSet and get global options for INLA
inla.getOption(option = NULL, list.out = NULL)
inla.setOption(...)The option to get. If option = NULL then
inla.getOption will return a named list of
current values, otherwise, option must be one (or a vector of several) of
The path to the inla-program.
Additional arguments to inla.call
Character string with the number of threads to use as
A:B, see ?inla
Sparse matrix library to use, one of band, taucs
(default) or pardiso
Run in safe-mode (ie try to automatically fix convergence errors)
(default TRUE)
Keep temporary files?
Verbose output?
Save memory at the cost of (minor) accuracy and computing time?
Do internal online optimisations or not
The name of the working directory.
Run the inla-program in a silent mode?
Run the inla-program in a debug mode?
The home of the Cygwin installation (default "C:/cygwin") (Remote computing for Windows only) (No longer in use!)
The ssh bind-adress (value of $SSH_AUTH_SOCK int the Cygwin-shell). (Remote computing for Windows only)
Give a warning for using the obsolete argument
graph.file instead of graph
The default value of argument scale.model which
optionally scale intrinisic models to have generalized unit average variance
Use a less verbose output for summary. Useful for
Markdown documents.
The timeout limit, in whole seconds, for calls to the inla binary. Default is 0, meaning no timeout limit. Set to a positive integer to terminate inla calls if they run to long. Fractional seconds are rounded up to the nearest integer. This feature is EXPERIMENTAL and might change at a later stage.
Which mode to use in INLA? Default is "compact". Other
options are "classic" and "twostage".
Which malloc library to use: "je", "tc", "mi", "compiler" or "default".
Option "compiler" use the compiler's implementation. The library
is loaded using LD_PRELOAD and similar functionality. Loosely, jemalloc is from Facebook,
tcmalloc is from Google and mimalloc is from Microsoft. This option is not available for
Windows and not all options might be available for every arch.
If malloc.lib is a complete path to an external library, that file will be used
instead of one of the supported ones.
Control use of fmesher methods during the transition
to a separate fmesher package. Only supported value is 2L, for using the
full range of fmesher package methods. A higher value may be used in the future
to force use of newer methods, but this is not currently implemented.
Default is 2L.
logical; whether to show warnings about deprecated
use of legacy INLA methods with fmesher package replacements. When TRUE,
shows deprecation messages for many CRS and mesh
related methods, pointing to their fm_* replacements. Default
since July 2025 is TRUE.
logical or character; at what minimum
severity to show warnings about deprecated
use of legacy INLA methods with fmesher package replacements.
When set to "default" (default), "soft", "warn", or "stop", indicates the
minimum warning level used when fmesher.evolution.warn is TRUE.
logical Do not use. By purpose left undocumented
logical Enable NUMA features (Linux only)
logical Disable warning about missing 'values'
logical; If TRUE, then inla.getOption will return a named
list of values, even if only one option is requested. Default is NULL,
which means that a named list will be returned if more than one option is
requested, and a single value will be returned if only one option is
requested. Using list.out = FALSE will return a plain vector of values,
without names, even if more than one option is requested; the data type may
depend on which options are requested, and may be unpredictable, so use only
if you know what you're doing.
Option and value, like option=value or option, value; see the Examples
## set number of threads
inla.setOption("num.threads", "4:1")
## alternative format
inla.setOption(num.threads="4:1")
## check it
inla.getOption("num.threads")
#> [1] "4:1"