inla.spde2.matern models.param2.matern.orig.RdConstruct parameter settings for inla.spde2.matern models.
The mesh to build the model on, as an fmesher::fm_mesh_2d()
object, or other fmesher mesh supporting fmesher::fm_dof(),
fmesher::fm_manifold_dim() and fmesher::fm_dof().
Fractional operator order, \(0<\alpha\leq 2\) supported. (\(\nu=\alpha-d/2\))
Matrix with specification of log-linear model for \(\tau\).
Matrix with specification of log-linear model for \(\kappa\).
Nominal prior mean for the field variance
Nominal prior mean for the spatial range
Prior mean for tau (overrides
prior.variance.nominal)
Prior mean for kappa (overrides
prior.range.nominal)
(overrides prior.*)
Scalar, vector or matrix, specifying the joint prior precision for \(theta\).