gammacount likelihoodpc-gammacount.RdFunctions to evaluate, sample, compute quantiles and percentiles of the PC
prior for the gammacount likelihood
inla.pc.rgammacount(n, lambda = 1)
inla.pc.dgammacount(x, lambda = 1, log = FALSE)
inla.pc.qgammacount(p, lambda = 1)
inla.pc.pgammacount(q, lambda = 1)inla.pc.dgammacount gives the density,
inla.pc.pgammacount gives the distribution function,
inla.pc.qgammacount gives the quantile function, and
inla.pc.rgammacount generates random deviates.
This gives the PC prior for the gammacount likelihood, which is the
PC prior for a in Gamma(a, 1) where Gamma(1, 1) is the
base model.
inla.doc("pc.gammacount")
x = inla.pc.rgammacount(100, lambda = 1)
d = inla.pc.dgammacount(x, lambda = 1)
x = inla.pc.qgammacount(0.5, lambda = 1)
inla.pc.pgammacount(x, lambda = 1)
#> [1] 0.5