plot.inla.mesh.Rd since
23.08.18.
Use fmesher::plot.fm_mesh_2d() or
fmesher::plot_rgl() instead.
Plots an inla.mesh() object using either standard graphics or
with rgl.
# S3 method for class 'inla.mesh'
plot(
x,
col = "white",
t.sub = 1:nrow(x$graph$tv),
add = FALSE,
lwd = 1,
xlim = range(x$loc[, 1]),
ylim = range(x$loc[, 2]),
main = NULL,
rgl = FALSE,
size = 2,
draw.vertices = FALSE,
vertex.color = "black",
draw.edges = TRUE,
edge.color = rgb(0.3, 0.3, 0.3),
draw.segments = draw.edges,
...
)An inla.mesh() object.
Color specification. A single named color, a vector of scalar
values, or a matrix of RGB values. Requires rgl=TRUE.
Optional triangle index subset to be drawn.
If TRUE, adds to the current plot instead of starting a
new one.
Line width for triangle edges.
X-axis limits.
Y-axis limits.
The main plot title. If not specified, a default title is generated based on the mesh type.
When TRUE, generates an rgl plot instead of a
generic graphics plot. Allows 3D plotting and color surface plotting.
Size of vertex points in rgl plotting. See
rgl.material.
If TRUE, draw triengle vertices.
Color specification for all vertices.
If TRUE, draw triangle edges.
Color specification for all edges.
If TRUE, draw boundary and interior constraint
edges more prominently.
Further graphics parameters, interpreted by the respective plotting systems.
mesh <- inla.mesh.create(globe = 10)
plot(mesh)
# \donttest{
if (require(rgl)) {
plot(mesh, rgl = TRUE, col = mesh$loc[, 1])
}
#> Error: The `rgl` argument of `plot.fm_mesh_2d()` was deprecated in fmesher
#> 0.1.0 and is now defunct.
#> ℹ Please use `plot_rgl()` instead.
# }