qreordering.RdThis function compute the reordering (or find the best reordering) using the GMRFLib implementation
inla.qreordering(graph, reordering = inla.reorderings())A (inla-)graph object
The name of the reordering algorithm to be used; either
one of the names listed in inla.reorderings(). The default is "auto"
which try several reordering algorithm and use the best one for this
particular matrix.
inla.qreordering returns a list with the name of the
reordering algorithm used or found, the reordering code for the reordering
algorithm, the actual reordering and its inverse.
g = system.file("demodata/germany.graph", package="INLA")
r = inla.qreordering(g)
m = inla.graph2matrix(g)
r = inla.qreordering(m)