remote.RdInitialize the definition file and print the path to the internal script to transfer ssh-keys
inla.ssh.copy.id()
inla.remote()inla.remote is used once to setup the remote host
information file (definition file) in the users home directory; see the FAQ
entry on this issue for more information. inla.ssh.copy.id will
return the path to the internal script to transfer ssh-keys.
##See the FAQ entry on this issue on r-inla.org.