rgeneric.RdA framework for defining latent models in R
inla.rgeneric.ar1.model(
cmd = c("graph", "Q", "mu", "initial", "log.norm.const", "log.prior", "quit"),
theta = NULL
)
inla.rgeneric.ar1.model.opt(
cmd = c("graph", "Q", "mu", "initial", "log.norm.const", "log.prior", "quit"),
theta = NULL
)
inla.rgeneric.iid.model(
cmd = c("graph", "Q", "mu", "initial", "log.norm.const", "log.prior", "quit"),
theta = NULL
)
inla.rgeneric.define(
model = NULL,
debug = FALSE,
compile = TRUE,
optimize = FALSE,
...
)
inla.rgeneric.wrapper(
cmd = c("graph", "Q", "mu", "initial", "log.norm.const", "log.prior", "quit"),
model,
theta = NULL
)
inla.rgeneric.q(
rmodel,
cmd = c("graph", "Q", "mu", "initial", "log.norm.const", "log.prior", "quit"),
theta = NULL
)An allowed request
Values of theta
The definition of the model; see inla.rgeneric.ar1.model
Logical. Enable debug output
Logical. Compile the definition of the model or not.
Logical. With this option TRUE, then model pass
only the values of Q and not the whole matrix. Please see the
vignette for details and inla.rgeneric.ar1.model.opt for an example.
Named list of variables that defines the environment of
model
The rgeneric model-object, the output of
inla.rgeneric.define
This allows a latent model to be defined in R. See
inla.rgeneric.ar1.model and inla.rgeneric.iid.model and the
documentation for worked out examples of how to define latent models in this
way. This will be somewhat slow and is intended for special cases and
protyping. The function inla.rgeneric.wrapper is for internal use
only.