sampler.RdProduce samples from the approximated joint posterior for the hyperparameters
inla.hyperpar.sample(n, result, intern = FALSE, improve.marginals = FALSE)Integer. Number of samples required.
An inla-object, f.ex the output from an
inla-call.
Logical. If TRUE then produce samples in the internal
scale for the hyperparmater, if FALSE then produce samples in the
user-scale. (For example log-precision (intern) and precision (user-scale))
Logical. If TRUE, then improve the samples
taking into account possible better marginal estimates for the
hyperparameters in result.
A matrix where each sample is a row. The contents of the column is described in the rownames.
n = 100
r = inla(y ~ 1 + f(idx), data = data.frame(y=rnorm(n), idx = 1:n))
ns = 500
x = inla.hyperpar.sample(ns, r)
rr = inla.hyperpar(r)
#> Warning: inla.hyperpar: Only for inla.mode='classic', skip...
xx = inla.hyperpar.sample(ns, rr, improve.marginals=TRUE)