This function provide access to the parameterisation of the scopy model

inla.scopy.define(n = 5L)

Arguments

n

Number of parameters, either 2 (intercept and slope) or >= 5 (intercept, slope and a spline representing the deviation from it)

Value

A list with the number of parameters and matrix defining basis vectors for the scopy model

Author

Havard Rue hrue@r-inla.org