scopyscopy.summary.RdThis function computes the mean and stdev for the spline function that is
implicite from an scopy model component
inla.scopy.summary(
result,
name,
mean.value = NULL,
slope.value = NULL,
by = 0.01,
range = c(0, 1),
debug = FALSE
)An inla-object, ie the output from an inla()
call
The name of the scopy model component see ?INLA::f
and argument scopy
In case where the mean of the spline is fixed and not estimated, you have to give it here
In case where the slope of the spline is fixed and not estimated, you have to give it here
The resolution of the results, in the scale where
diff(range(locations)) is 1
The range of the locations, as c(from, to)
If TRUE then enable some debug output
A data.frame with locations, mean and stdev. If name
is not found, NULL is returned.
## see example in inla.doc("scopy")