summary.RdTakes a fitted inla or surv.inla object produced by
inla or surv.inla and produces a summary from it.
summary.inla returns an object of class summary.inla,
a list of components to print.
Posterior mean and standard deviation (together with quantiles or cdf) are printed for the fixed effects in the model.
For the random effects the function summary() prints the posterior
mean and standard deviations for the hyperparameters
If the option short.summary is set to TRUE using
inla.setOption, then a less verbose summary variant will be used,
which might be more suitable for Markdown documents.