Show the version of the INLA-package

inla.version(what = c("default", "version", "date"))

Arguments

what

What to show version of

Value

inla.version display the current version information using cat with default or info, or return other specific requests through the call.

Author

Havard Rue hrue@r-inla.org

Examples


## Summary of all
inla.version()
#> 	R-INLA version ..........: 26.03.19
#> 	Date ....................: 2026-04-04
#> 	Maintainers .............: Havard Rue <hrue@r-inla.org>
#> 	                         : Finn Lindgren <finn.lindgren@gmail.com>
#> 	                         : Elias Teixeira Krainski <elias@r-inla.org>
#> 	Main web-page ...........: www.r-inla.org
#> 	Download-page ...........: inla.r-inla-download.org
#> 	Repository ..............: github.com/hrue/r-inla
#> 	Email support ...........: help@r-inla.org
#> 	                         : r-inla-discussion-group@googlegroups.com
## The building date
inla.version("date")
#> [1] "2026-04-04"