control.expert.RdControl variables in control.* for use with inla().
The functions can be used to TAB-complete arguments, and
returns a list of the default control arguments, unless overridden by
specific input arguments.
control.expert(
cpo.manual = FALSE,
cpo.idx = -1,
disable.gaussian.check = FALSE,
jp = NULL,
globalconstr = list(A = NULL, e = NULL),
opt.solve = FALSE,
opt.storage = FALSE,
opt.num.threads = TRUE
)
inla.set.control.expert.default(...)A boolean variable to decide if the inla-program is to be runned in a manual-cpo-mode. (EXPERT OPTION: DO NOT USE)
The index/indices of the data point(s) to remove. (EXPERIMENTAL OPTION: DO NOT USE)
Disable the check for fast computations with a
Gaussian likelihood and identity link (default FALSE)
An object of class inla.jp defining a joint prior
Add a global constraint (see ?f and argument
extraconstr). Note that a global constraint does NOT
correct the normalisation constant.
(EXPERIMENTAL OPTION)
Store also L^T to optimize linear solves (TAUCS only).
Might benefite larger models. (EXPERIMENTAL OPTION)
Make sure L is stored sequencially (TAUCS only).
Might benefite larger models. (EXPERIMENTAL OPTION)
Reduce the number of threads adaptively if needed at critical places to optimize wall-clock time
Named arguments passed on to the main function
Other control:
control.bgev(),
control.compute(),
control.family(),
control.fixed(),
control.gcpo(),
control.group(),
control.hazard(),
control.inla(),
control.lincomb(),
control.link(),
control.lp.scale(),
control.mix(),
control.mode(),
control.numa(),
control.pardiso(),
control.pom(),
control.predictor(),
control.scopy(),
control.sem(),
control.stiles(),
control.taucs(),
control.update(),
control.vb()