inla.diameter.Rd since
23.08.18.
Use fmesher::fm_diameter() instead.
Find an upper bound to the convex hull of a point set
inla.diameter(x, ...)A point set as an \(n\times d\) matrix, or an fmesher::fm_mesh_2d()] related object.
Additional parameters passed on to fmesher::fm_diameter().
A scalar, upper bound for the diameter of the convex hull of the point set.
inla.diameter(matrix(c(0, 1, 1, 0, 0, 0, 1, 1), 4, 2))
#> Warning: `inla.diameter()` was deprecated in INLA 23.08.18.
#> ℹ Please use `fmesher::fm_diameter()` instead.
#> ℹ For more information, see
#> https://inlabru-org.github.io/fmesher/articles/inla_conversion.html
#> ℹ To silence these deprecation messages in old legacy code, set
#> `inla.setOption(fmesher.evolution.warn = FALSE)`.
#> ℹ To ensure visibility of these messages in package tests, also set
#> `inla.setOption(fmesher.evolution.verbosity = 'warn')`.
#> [1] 1.414214