inla.fmesher.smorg.Rd since
23.08.18.
Use the methods in the fmesher package
instead; see details below.
Low level function for computing finite element matrices, spherical harmonics, B-splines, and point mappings with barycentric triangle coordinates.
inla.fmesher.smorg(
loc,
tv,
fem = NULL,
aniso = NULL,
gradients = FALSE,
sph0 = deprecated(),
sph = deprecated(),
bspline = NULL,
points2mesh = NULL,
splitlines = NULL,
output = NULL,
keep = FALSE
)3-column triangle vertex coordinate matrix.
3-column triangle vertex index matrix.
Use
fmesher::fm_fem() instead.
Maximum finite element matrix order to be computed.
Use
fmesher::fm_fem() instead.
A two-element list with \(\gamma\) and \(v\) for
an anisotropic operator \(\nabla\cdot H \nabla\), where
\(H=\gamma I + v v^\top\)
Use
fmesher::fm_fem() instead.
When TRUE, calculate derivative operator matrices
dx, dy, and dz.
Use
fmesher::fm_raw_basis() instead.
Use
fmesher::fm_raw_basis() instead.
Use
fmesher::fm_raw_basis() instead.
Rotationally invariant B-splines on a sphere. 3-vector with
number of basis functions n, basis degree degree, and a
logical; TRUE uniform knot angles, FALSE for uniform spacing
in \(\sin(latitude)\).
Use
fmesher::fm_bary() instead.
3-column matrix with points to be located in the mesh.
Use
fmesher::fm_split_lines() or
fmesher::fmesher_split_lines() instead.
A list with elements loc (3-column coordinate
matrix) and idx (2-column index matrix) describing line segments that
are to be split into sub-segments at triangle boundaries.
Names of objects to be included in the output, if different from defaults.
When TRUE, for debugging purposes keep the fmesher
I/O files on disk.
A list of generated named quantities.