inla.tempdir.Rd
inla.tempdir
inla.tempdir()
Return the name, and create, a temporary directory for storing intermediate results. This function is exported as it is also used by package INLAjoint (for details, check the INLAjoint implementation)
INLAjoint