pc-cormat.RdFunctions to evaluate and sample from the PC prior for a correlation matrix.
The parameterisation of a correlation matrix of dimension p has
dim parameters: theta which are in the interval -pi to pi.
The alternative parameterisation is through the off-diagonal elements
r of the correlation matrix R. The functions
inla.pc.cormat.<A>2<B> convert between parameterisations <A>
to parameterisations <B>, where both <A> and <B> are
one of theta, r and R, and p and dim.
inla.pc.cormat.dim2p(dim)
inla.pc.cormat.p2dim(p)
inla.pc.cormat.theta2R(theta)
inla.pc.cormat.R2theta(R)
inla.pc.cormat.r2R(r)
inla.pc.cormat.R2r(R)
inla.pc.cormat.r2theta(r)
inla.pc.cormat.theta2r(theta)
inla.pc.cormat.permute(R)
inla.pc.cormat.rtheta(n = 1, p, lambda = 1)
inla.pc.cormat.dtheta(theta, lambda = 1, log = FALSE)The dimension of theta, the parameterisatin of the
correlation matrix
The dimension the correlation matrix
A vector of parameters for the correlation matrix
A correlation matrix
The off diagonal elements of a correlation matrix
Number of observations
The rate parameter in the prior
Logical. Return the density in natural or log-scale.
inla.pc.cormat.rtheta generate samples from the prior,
returning a matrix where each row is a sample of theta.
inla.pc.cormat.dtheta evaluates the density of theta.
inla.pc.cormat.permute randomly permutes a correlation matrix, which
is useful if an exchangable sample of a correlation matrix is required.
p = 4
print(paste("theta has length", inla.pc.cormat.p2dim(p)))
#> [1] "theta has length 6"
theta = inla.pc.cormat.rtheta(n=1, p=4, lambda = 1)
print("sample theta:")
#> [1] "sample theta:"
print(theta)
#> [,1] [,2] [,3] [,4] [,5] [,6]
#> [1,] 1.517243 1.61125 1.521007 1.552252 1.538682 1.651778
print(paste("log.dens", inla.pc.cormat.dtheta(theta, log=TRUE)))
#> [1] "log.dens 8.02815372418386"
print("r:")
#> [1] "r:"
r = inla.pc.cormat.theta2r(theta)
print(r)
#> [1] 0.05352802 -0.04044307 0.04976899 0.01633623 0.03468732 -0.08208997
print("A sample from the non-exchangable prior, R:")
#> [1] "A sample from the non-exchangable prior, R:"
R = inla.pc.cormat.r2R(r)
print(R)
#> [,1] [,2] [,3] [,4]
#> [1,] 1.00000000 0.05352802 -0.04044307 0.04976899
#> [2,] 0.05352802 1.00000000 0.01633623 0.03468732
#> [3,] -0.04044307 0.01633623 1.00000000 -0.08208997
#> [4,] 0.04976899 0.03468732 -0.08208997 1.00000000
print("A sample from the exchangable prior, R:")
#> [1] "A sample from the exchangable prior, R:"
R = inla.pc.cormat.permute(R)
print(R)
#> [,1] [,2] [,3] [,4]
#> [1,] 1.00000000 0.04976899 0.03468732 -0.04044307
#> [2,] 0.04976899 1.00000000 -0.08208997 0.01633623
#> [3,] 0.03468732 -0.08208997 1.00000000 0.05352802
#> [4,] -0.04044307 0.01633623 0.05352802 1.00000000