prw2.range.RdFunctions to evaluate, sample, compute quantiles and percentiles of the PC prior for the range parameter in the PRW2 model.
prw2.d(rho)inla.prw2.drange gives the density, inla.prw2.prange gives the distribution
function, inla.prw2.qrange gives the quantile function, and inla.prw2.rrange
generates random deviates.
The statement Prob(range > r0) = alpha is used to determine
lambda unless lambda is given.
The 'r' and 'q' functions are quite slow as the quantile-function needs to be computed.
inla.doc("pc.prw2.range")